#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-HuB1yM6bXVJ7GeLJiyeFRP
key:                  postgrest-10.1.0-HuB1yM6bXVJ7GeLJiyeFRP
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  01409a3c4051fc466d72543b3ffa75d7
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-HuB1yM6bXVJ7GeLJiyeFRP
depends:
    HTTP-4000.5.0-3Gya2D2hFHW9tWhLv9Wzif
    Ranged-sets-0.5.0-Wgw1NjMr2uL0T0IHZWCfE
    aeson-2.2.2.0-EED32RMVwDLAiFjSZ5pcFd
    auto-update-0.1.6-3TnGjpzFZRI1vJ92atedKk base-4.18.2.1
    base64-bytestring-1.2.1.0-CjkCegEzHzaEa0Qvqn5r7i
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-6POLtE8S4Zy4iSjbLMqgkn
    cassava-0.5.4.1-6uVTNgHheD54ix0qkI0zvr
    configurator-pg-0.2.11-9Iaw5xtFBa62efSbw9aL52 containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-LBP8mV18sfk1Qag8dTBxyF
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-ApVK27wjltA583wqtj3YyG
    hasql-dynamic-statements-0.3.1.2-6KsjeEpA9DNA48DEzrrva8
    hasql-notifications-0.2.0.6-BB5HnazLp0F7w4tuygGim2
    hasql-pool-0.8.0.2-HKnX8vW4NMlLkSNfODpEb5
    hasql-transaction-1.0.1.2-AwP5AXCMUR9LniG2AbkMXy
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-3SRp0qHlnI76ALPv5yfzvg
    insert-ordered-containers-0.2.5.3-HDIFMhHKEKIChypyeyzlYO
    interpolatedstring-perl6-1.0.2-JoaHt95uOOcB0GqLRO2FVb
    jose-0.10.0.1-5Dn3nZEY34fBrEDR8TZwdD
    lens-5.3.5-2PHdo10s430JaBSjTb6pzS
    lens-aeson-1.2.3-3Wo8cifeHRJ2spDotqOpud mtl-2.3.1
    network-3.1.4.0-8bVD9DiLdB7AtkTNcfBrB8
    network-uri-2.6.4.2-AAuJwobb8qV67gBUtHYQFB
    optparse-applicative-0.18.1.0-AY6j66qHG9N8it59DfXOA5
    parsec-3.1.16.1 protolude-0.3.5-JH7iEAQP6gfF6Qv3EuXHzS
    regex-tdfa-1.3.2.5-I357RwqJfbqBm17EQ0nFad
    retry-0.9.3.1-J77hNAZF92LLCkB9zbRFql
    scientific-0.3.8.1-49XIes4ZRgiBro3MxA36YN
    swagger2-2.9-A0aTAGgsEGHGKMom39pA5w text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-9xqafn4Eq4w4BZS2LI6Zwa
    vault-0.3.1.6-JyQmpWTb03Z3m5E3kbHG3C
    vector-0.13.2.0-GxJ3o7ubGCR5jPPfpyxiRl
    wai-3.2.4-LAI7Peo74UPFcqcGYSLYIx
    wai-cors-0.2.7-JE2NHfeKoaz135lrYqYouX
    wai-extra-3.1.18-4DVbRyKBrtpGLxVhIvuLlM
    wai-logger-2.5.0-CKLa2vwNoyVIOMMQll9rol
    warp-3.4.0-1FKNqUL3YvcCqaBHBs8d8c

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

